pub struct Mailbox<T: UnreliablePolicy>(/* private fields */);Expand description
A mailbox wraps a sender for messages of type T.
Implementations
Sourceimpl<P: PublicKey, O: Sink, I: Stream> Mailbox<Message<O, I, P>>
impl<P: PublicKey, O: Sink, I: Stream> Mailbox<Message<O, I, P>>
Sourcepub fn spawn(
&mut self,
connection: (Sender<O>, Receiver<I>),
reservation: Reservation<P>,
) -> Unreliable<Feedback>
pub fn spawn( &mut self, connection: (Sender<O>, Receiver<I>), reservation: Reservation<P>, ) -> Unreliable<Feedback>
Send a message to the actor to spawn a new task for the given peer.
This may be rejected when the spawner is backlogged, or return closed after shutdown, which is harmless since stale connections do not need to be spawned.
Sourceimpl<Si: Sink, St: Stream, P: PublicKey> Mailbox<Message<Si, St, P>>
impl<Si: Sink, St: Stream, P: PublicKey> Mailbox<Message<Si, St, P>>
Sourcepub fn spawn(
&mut self,
connection: (Sender<Si>, Receiver<St>),
reservation: Reservation<P>,
) -> Unreliable<Feedback>
pub fn spawn( &mut self, connection: (Sender<Si>, Receiver<St>), reservation: Reservation<P>, ) -> Unreliable<Feedback>
Send a message to the actor to spawn a new task for the given peer.
This may be rejected when the spawner is backlogged, or return closed after shutdown, which is harmless since stale connections do not need to be spawned.
Sourceimpl<T: UnreliablePolicy> Mailbox<T>
impl<T: UnreliablePolicy> Mailbox<T>
Sourcepub fn new(
metrics: impl Metrics,
size: NonZeroUsize,
) -> (Self, UnreliableReceiver<T>)
pub fn new( metrics: impl Metrics, size: NonZeroUsize, ) -> (Self, UnreliableReceiver<T>)
Returns a new mailbox with the given sender.