pub struct Network<E: RNetwork + Spawner + Rng + Clock + Metrics, P: PublicKey> { /* private fields */ }Expand description
Implementation of a simulated network.
Implementations
Sourceimpl<E: RNetwork + Spawner + Rng + Clock + Metrics, P: PublicKey> Network<E, P>
impl<E: RNetwork + Spawner + Rng + Clock + Metrics, P: PublicKey> Network<E, P>
Sourcepub fn new(context: E, cfg: Config) -> (Self, Oracle<P, E>)
pub fn new(context: E, cfg: Config) -> (Self, Oracle<P, E>)
Create a new simulated network with a given runtime and configuration.
Returns a tuple containing the network instance and the oracle that can be used to modify the state of the network during context.
Sourcepub async fn new_with_peers<I>(
context: E,
cfg: Config,
peers: I,
) -> (Self, Oracle<P, E>)where
I: IntoIterator<Item = P>,
pub async fn new_with_peers<I>(
context: E,
cfg: Config,
peers: I,
) -> (Self, Oracle<P, E>)where
I: IntoIterator<Item = P>,
Create a new simulated network with an initial primary peer set.
This is a convenience for test setups that would otherwise call
crate::Manager::track immediately after construction.
Sourcepub async fn new_with_split_peers<I, J>(
context: E,
cfg: Config,
primary: I,
secondary: J,
) -> (Self, Oracle<P, E>)where
I: IntoIterator<Item = P>,
J: IntoIterator<Item = P>,
pub async fn new_with_split_peers<I, J>(
context: E,
cfg: Config,
primary: I,
secondary: J,
) -> (Self, Oracle<P, E>)where
I: IntoIterator<Item = P>,
J: IntoIterator<Item = P>,
Create a new simulated network with primary and secondary peers split into two sets.
Peers are tracked at peer set ID 0 as TrackedPeers, matching the most common test
setup.