pub struct PeerSetUpdate<P: PublicKey> {
pub index: u64,
pub latest: TrackedPeers<P>,
pub all: TrackedPeers<P>,
}Expand description
Notification sent to subscribers when a peer set changes.
Fields
index: u64The index of the peer set that changed.
latest: TrackedPeers<P>The primary and secondary peers in the new set.
all: TrackedPeers<P>Union of primary and secondary peers across all tracked peer sets.